import { defineStore } from 'pinia';
import { fetchAddCategory, fetchDeleteCategory, fetchGetCategoryAllList, fetchGetCategoryList, fetchUpdateCategory } from '@/api/v1/financial/admin/category';
import { pageSizes } from '@/enums/baseConstant';
import { storeMessage } from '@/utils/message';
import { storePagination } from '@/store/useStorePagination';

/**
 * 分类信息 Store
 */
export const useCategoryStore = defineStore('categoryStore', {
	state() {
		return {
			// 分类信息列表
			datalist: [],
			// 所有分类
			allCategoryList: [],
			// 查询表单
			form: {
				// 绑定的用户id
				userId: undefined,
				// 分类名称
				categoryName: undefined,
				// 是否内置字段
				isBuiltin: undefined,
			},
			// 分页查询结果
			pagination: {
				currentPage: 1,
				pageSize: 30,
				total: 1,
				pageSizes,
			},
			// 加载
			loading: false,
		};
	},
	getters: {},
	actions: {
		/** 获取分类信息 */
		async getCategoryList() {
			// 整理请求参数
			const data = { ...this.pagination, ...this.form };
			delete data.pageSizes;
			delete data.total;
			delete data.background;

			// 获取分类信息列表
			const result = await fetchGetCategoryList(data);

			// 公共页面函数hook
			const pagination = storePagination.bind(this);
			return pagination(result);
		},

		/** 查询当前用户下所有的分类 */
		async getCategoryAllList(data: any) {
			const result = await fetchGetCategoryAllList(data);
			if (result.code === 200) {
				this.allCategoryList = result.data;
			}
		},

		/** 添加分类信息 */
		async addCategory(data: any) {
			const result = await fetchAddCategory(data);
			return storeMessage(result);
		},

		/** 修改分类信息 */
		async updateCategory(data: any) {
			const result = await fetchUpdateCategory(data);
			return storeMessage(result);
		},

		/** 删除分类信息 */
		async deleteCategory(data: any) {
			const result = await fetchDeleteCategory(data);
			return storeMessage(result);
		},
	},
});
