import { defineStore } from 'pinia';
import {
	fetchAddDebtRepaymentPlan,
	fetchDeleteDebtRepaymentPlan,
	fetchGetDebtRepaymentPlanList,
	fetchUpdateDebtRepaymentPlan,
} from '@/api/v1/financial/admin/debtRepaymentPlan';
import { pageSizes } from '@/enums/baseConstant';
import { storeMessage } from '@/utils/message';
import { storePagination } from '@/store/useStorePagination';

/**
 * 债务还款计划表 Store
 */
export const useDebtRepaymentPlanStore = defineStore('debtRepaymentPlanStore', {
	state() {
		return {
			// 债务还款计划表列表
			datalist: [],
			// 查询表单
			form: {
				// 用户Id
				userId: undefined,
				// 债务ID
				debtId: undefined,
				// 债务金额
				installmentNumber: undefined,
				// 每期应还金额
				installmentAmount: undefined,
				// 还款截止日期
				dueDate: undefined,
				// 已还金额
				paidAmount: undefined,
				// 还款状态
				paymentStatus: undefined,
			},
			// 分页查询结果
			pagination: {
				currentPage: 1,
				pageSize: 30,
				total: 1,
				pageSizes,
			},
			// 加载
			loading: false,
		};
	},
	getters: {},
	actions: {
		/** 获取债务还款计划表 */
		async getDebtRepaymentPlanList() {
			// 整理请求参数
			const data = { ...this.pagination, ...this.form };
			delete data.pageSizes;
			delete data.total;
			delete data.background;

			// 获取债务还款计划表列表
			const result = await fetchGetDebtRepaymentPlanList(data);

			// 公共页面函数hook
			const pagination = storePagination.bind(this);
			return pagination(result);
		},

		/** 添加债务还款计划表 */
		async addDebtRepaymentPlan(data: any) {
			const result = await fetchAddDebtRepaymentPlan(data);
			return storeMessage(result);
		},

		/** 修改债务还款计划表 */
		async updateDebtRepaymentPlan(data: any) {
			const result = await fetchUpdateDebtRepaymentPlan(data);
			return storeMessage(result);
		},

		/** 删除债务还款计划表 */
		async deleteDebtRepaymentPlan(data: any) {
			const result = await fetchDeleteDebtRepaymentPlan(data);
			return storeMessage(result);
		},
	},
});
