import { defineStore } from 'pinia';
import {
	fetchAddUserBill,
	fetchDeleteUserBill,
	fetchExportBill,
	fetchGetUserBillList,
	fetchImportBill,
	fetchUpdateUserBill,
} from '@/api/v1/financial/user/billUser';
import { pageSizes } from '@/enums/baseConstant';
import { storeMessage } from '@/utils/message';
import { storePagination } from '@/store/useStorePagination';
import { getCurrentMouthDate } from '@/utils/date';
import dayjs from 'dayjs';
import { download } from '@/utils/sso';

/**
 * 账单信息 Store
 */
export const useBillUserStore = defineStore('billUserStore', {
	state() {
		return {
			// 账单信息列表
			datalist: [],
			// 收入和支出
			expendWithIncomeList: [],
			// 查询表单
			form: {
				// 类型：1 - 收入，-1 - 支出
				type: undefined,
				// 金额
				amount: undefined,
				// 描述
				description: undefined,
				// 开始交易日期
				startDate: undefined,
				// 结束交易日期
				endDate: undefined,
				// 交易日期
				date: getCurrentMouthDate(),
			},
			// 分页查询结果
			pagination: {
				currentPage: 1,
				pageSize: 30,
				total: 1,
				pageSizes,
			},
			// 加载
			loading: false,
		};
	},
	actions: {
		/** 获取账单信息 */
		async getBillList() {
			// 将日期格式赋值
			if (this.form.date) {
				this.form.startDate = this.form.date[0];
				this.form.endDate = this.form.date[1];
			}

			// 整理请求参数
			const data = { ...this.pagination, ...this.form };
			delete data.pageSizes;
			delete data.total;
			delete data.background;

			// 获取账单信息列表
			const result = await fetchGetUserBillList(data);

			// 公共页面函数hook
			const pagination = storePagination.bind(this);
			return pagination(result);
		},

		/** 导入账单*/
		async importBill(data: any) {
			const result = await fetchImportBill(data);
			return storeMessage(result);
		},

		/** 导出账单*/
		async exportBill(data: any) {
			data = { startDate: dayjs(data[0]).format('YYYY-MM-DD'), endDate: dayjs(data[1]).format('YYYY-MM-DD') };
			const result = await fetchExportBill(data);
			download(result, `${data.startDate}~${data.endDate}.xlsx`);
		},

		/** 添加账单信息 */
		async addBill(data: any) {
			const result = await fetchAddUserBill(data);
			return storeMessage(result);
		},

		/** 修改账单信息 */
		async updateBill(data: any) {
			const result = await fetchUpdateUserBill(data);
			return storeMessage(result);
		},

		/** 删除账单信息 */
		async deleteBill(data: any) {
			const result = await fetchDeleteUserBill(data);
			return storeMessage(result);
		},
	},
	getters: {},
});
