import { defineStore } from 'pinia';
import {
	fetchAddCategoryUser,
	fetchDeleteCategoryUser,
	fetchGetCategoryUserAllList,
	fetchGetCategoryUserList,
	fetchUpdateCategoryUser,
} from '@/api/v1/financial/user/categoryUser';
import { pageSizes } from '@/enums/baseConstant';
import { storeMessage } from '@/utils/message';
import { storePagination } from '@/store/useStorePagination';

/**
 * 分类信息 Store
 */
export const useCategoryUserStore = defineStore('categoryUserStore', {
	state() {
		return {
			// 分类信息列表
			datalist: [],
			// 所有分类
			allCategoryList: [],
			// 查询表单
			form: {
				// 分类名称
				categoryName: undefined,
				// 是否内置字段
				isBuiltin: undefined,
			},
			// 分页查询结果
			pagination: {
				currentPage: 1,
				pageSize: 30,
				total: 1,
				pageSizes,
			},
			// 加载
			loading: false,
		};
	},
	getters: {},
	actions: {
		/** 获取分类信息 */
		async getCategoryUserList() {
			// 整理请求参数
			const data = { ...this.pagination, ...this.form };
			delete data.pageSizes;
			delete data.total;
			delete data.background;

			// 获取分类信息列表
			const result = await fetchGetCategoryUserList(data);

			// 公共页面函数hook
			const pagination = storePagination.bind(this);
			return pagination(result);
		},

		/** 查询当前用户下所有的分类 */
		async getCategoryUserAllList() {
			const result = await fetchGetCategoryUserAllList();
			if (result.code === 200) {
				this.allCategoryList = result.data;
			}
		},

		/** 添加分类信息 */
		async addCategoryUser(data: any) {
			const result = await fetchAddCategoryUser(data);
			return storeMessage(result);
		},

		/** 修改分类信息 */
		async updateCategoryUser(data: any) {
			const result = await fetchUpdateCategoryUser(data);
			return storeMessage(result);
		},

		/** 删除分类信息 */
		async deleteCategoryUser(data: any) {
			const result = await fetchDeleteCategoryUser(data);
			return storeMessage(result);
		},
	},
});
