import { addDialog } from '@/components/BaseDialog/index';
import CategoryUserDialog from '@/views/financial-user/account-bill/category/category-user-dialog.vue';
import { useCategoryUserStore } from '@/store/financialUser/categoryUser';
import { h, ref } from 'vue';
import { message, messageBox } from '@/utils/message';
import type { FormItemProps } from '@/views/financial-user/account-bill/category/utils/types';
import { $t } from '@/plugins/i18n';
import DeleteBatchDialog from '@/components/Table/DeleteBatchDialog.vue';

export const formRef = ref();
// 删除ids
export const deleteIds = ref([]);
const categoryUserStore = useCategoryUserStore();

/** 搜索初始化分类信息 */
export async function onSearch() {
	categoryUserStore.loading = true;
	await categoryUserStore.getCategoryUserList();
	categoryUserStore.loading = false;
}

/** 添加分类信息 */
export function onAdd() {
	addDialog({
		title: `${$t('addNew')}${$t('categoryUser')}`,
		width: '30%',
		props: {
			formInline: {
				categoryName: undefined,
			},
		},
		draggable: true,
		fullscreenIcon: true,
		closeOnClickModal: false,
		contentRenderer: () => h(CategoryUserDialog, { ref: formRef }),
		beforeSure: (done, { options }) => {
			const form = options.props.formInline as FormItemProps;
			formRef.value.formRef.validate(async (valid: any) => {
				if (!valid) return;

				const result = await categoryUserStore.addCategoryUser(form);
				if (!result) return;
				done();
				await onSearch();
			});
		},
	});
}

/** 更新分类信息 */
export function onUpdate(row: any) {
	addDialog({
		title: `${$t('modify')}${$t('categoryUser')}`,
		width: '30%',
		props: {
			formInline: {
				categoryName: row.categoryName,
			},
		},
		draggable: true,
		fullscreenIcon: true,
		closeOnClickModal: false,
		contentRenderer: () => h(CategoryUserDialog, { ref: formRef }),
		beforeSure: (done, { options }) => {
			const form = options.props.formInline as FormItemProps;
			formRef.value.formRef.validate(async (valid: any) => {
				if (!valid) return;

				const result = await categoryUserStore.updateCategoryUser({ ...form, id: row.id });
				if (!result) return;
				done();
				await onSearch();
			});
		},
	});
}

/** 删除分类信息 */
export const onDelete = async (row: any) => {
	const id = row.id;

	// 是否确认删除
	const result = await messageBox({
		title: $t('confirmDelete'),
		showMessage: false,
		confirmMessage: undefined,
		cancelMessage: $t('cancel_delete'),
	});
	if (!result) return;

	// 删除数据
	await categoryUserStore.deleteCategoryUser([id]);
	await onSearch();
};

/** 批量删除 */
export const onDeleteBatch = async () => {
	const ids = deleteIds.value;
	const formDeletedBatchRef = ref();

	addDialog({
		title: $t('deleteBatchTip'),
		width: '30%',
		props: { formInline: { confirmText: '' } },
		draggable: true,
		fullscreenIcon: true,
		closeOnClickModal: false,
		contentRenderer: () => h(DeleteBatchDialog, { ref: formDeletedBatchRef }),
		beforeSure: (done, { options }) => {
			formDeletedBatchRef.value.formDeletedBatchRef.validate(async (valid: any) => {
				if (!valid) return;

				const text = options.props.formInline.confirmText.toLowerCase();
				if (text === 'yes' || text === 'y') {
					// 删除数据
					await categoryUserStore.deleteCategoryUser(ids);
					await onSearch();

					done();
				} else message($t('deleteBatchTip'), { type: 'warning' });
			});
		},
	});
};
