import { addDialog } from '@/components/BaseDialog/index';
import BudgetCategoryDialog from '@/views/financial/budget-saving/budget-category/budget-category-dialog.vue';
import { useBudgetCategoryStore } from '@/store/financial/budgetCategory';
import { h, ref } from 'vue';
import { message, messageBox } from '@/utils/message';
import type { FormItemProps } from '@/views/financial/budget-saving/budget-category/utils/types';
import { $t } from '@/plugins/i18n';
import DeleteBatchDialog from '@/components/Table/DeleteBatchDialog.vue';

export const formRef = ref();
// 删除ids
export const deleteIds = ref([]);
const budgetCategoryStore = useBudgetCategoryStore();

/** 搜索初始化预算分类表 */
export async function onSearch() {
	budgetCategoryStore.loading = true;
	await budgetCategoryStore.getBudgetCategoryList();
	budgetCategoryStore.loading = false;
}

/** 添加预算分类表 */
export function onAdd(parentId: string = '0') {
	addDialog({
		title: `${$t('addNew')}${$t('budgetCategory')}`,
		width: '30%',
		props: {
			formInline: {
				parentId,
				categoryName: undefined,
				budgetName: undefined,
				statusType: undefined,
				amount: undefined,
				period: undefined,
				startPeriod: undefined,
				endPeriod: undefined,
			},
		},
		draggable: true,
		fullscreenIcon: true,
		closeOnClickModal: false,
		contentRenderer: () => h(BudgetCategoryDialog, { ref: formRef }),
		beforeSure: (done, { options }) => {
			const form = options.props.formInline as FormItemProps;
			formRef.value.formRef.validate(async (valid: any) => {
				if (!valid) return;

				// 格式化开始时间和结束时间
				form.startPeriod = form.period[0];
				form.endPeriod = form.period[1];

				const result = await budgetCategoryStore.addBudgetCategory(form);
				if (!result) return;
				done();
				await onSearch();
			});
		},
	});
}

/** 更新预算分类表 */
export function onUpdate(row: any) {
	addDialog({
		title: `${$t('modify')}${$t('budgetCategory')}`,
		width: '30%',
		props: {
			formInline: {
				parentId: row.parentId ? row.parentId : '0',
				userId: row.userId,
				categoryName: row.categoryName,
				budgetName: row.budgetName,
				statusType: row.statusType,
				amount: row.amount,
				period: [row.startPeriod, row.endPeriod],
				startPeriod: row.startPeriod,
				endPeriod: row.endPeriod,
			},
		},
		draggable: true,
		fullscreenIcon: true,
		closeOnClickModal: false,
		contentRenderer: () => h(BudgetCategoryDialog, { ref: formRef }),
		beforeSure: (done, { options }) => {
			const form = options.props.formInline as FormItemProps;
			formRef.value.formRef.validate(async (valid: any) => {
				if (!valid) return;

				// 格式化开始时间和结束时间
				form.startPeriod = form.period[0];
				form.endPeriod = form.period[1];

				const result = await budgetCategoryStore.updateBudgetCategory({ ...form, id: row.id });
				if (!result) return;
				done();
				await onSearch();
			});
		},
	});
}

/** 删除预算分类表 */
export const onDelete = async (row: any) => {
	const id = row.id;

	// 是否确认删除
	const result = await messageBox({
		title: $t('confirmDelete'),
		showMessage: false,
		confirmMessage: undefined,
		cancelMessage: $t('cancel_delete'),
	});
	if (!result) return;

	// 删除数据
	await budgetCategoryStore.deleteBudgetCategory([id]);
	await onSearch();
};

/** 批量删除 */
export const onDeleteBatch = async () => {
	const ids = deleteIds.value;
	const formDeletedBatchRef = ref();

	addDialog({
		title: $t('deleteBatchTip'),
		width: '30%',
		props: { formInline: { confirmText: '' } },
		draggable: true,
		fullscreenIcon: true,
		closeOnClickModal: false,
		contentRenderer: () => h(DeleteBatchDialog, { ref: formDeletedBatchRef }),
		beforeSure: (done, { options }) => {
			formDeletedBatchRef.value.formDeletedBatchRef.validate(async (valid: any) => {
				if (!valid) return;

				const text = options.props.formInline.confirmText.toLowerCase();
				if (text === 'yes' || text === 'y') {
					// 删除数据
					await budgetCategoryStore.deleteBudgetCategory(ids);
					await onSearch();

					done();
				} else message($t('deleteBatchTip'), { type: 'warning' });
			});
		},
	});
};
