import { reactive } from 'vue';
import { $t } from '@/plugins/i18n';
import { ElText, type FormRules } from 'element-plus';

// 表格列
export const columns: TableColumnList = [
	{ type: 'selection', align: 'left' },
	{ type: 'index', index: (index: number) => index + 1, label: '序号', width: 60 },
	// 债务金额
	{
		label: $t('installmentNumber'),
		prop: 'installmentNumber',
		formatter({ installmentNumber }) {
			return (
				<ElText style={{ fontWeight: 800 }} type={'info'} size={'large'}>
					{installmentNumber}￥
				</ElText>
			);
		},
	},
	// 每期应还金额
	{
		label: $t('installmentAmount'),
		prop: 'installmentAmount',
		formatter({ installmentAmount }) {
			return (
				<ElText style={{ fontWeight: 800 }} type={'info'} size={'large'}>
					{installmentAmount}￥
				</ElText>
			);
		},
	},
	// 已还金额
	{
		label: $t('paidAmount'),
		prop: 'paidAmount',
		formatter({ paidAmount }) {
			return (
				<ElText style={{ fontWeight: 800 }} type={'info'} size={'large'}>
					{paidAmount}￥
				</ElText>
			);
		},
	},
	// 还款状态
	{ label: $t('paymentStatus'), prop: 'paymentStatus', slot: 'paymentStatus' },
	// 还款截止日期
	{
		label: $t('dueDate'),
		prop: 'dueDate',
		sortable: true,
		formatter({ dueDate }) {
			return (
				<ElText type={'danger'} style={{ fontWeight: 800 }}>
					{dueDate}
				</ElText>
			);
		},
		width: 190,
	},
	{ label: $t('table.updateTime'), prop: 'updateTime', sortable: true, width: 160 },
	{ label: $t('table.createTime'), prop: 'createTime', sortable: true, width: 160 },
	// 绑定的用户
	{ label: $t('username'), prop: 'username', slot: 'username', width: 130 },
	{ label: $t('table.createUser'), prop: 'createUser', slot: 'createUser', width: 130 },
	{ label: $t('table.updateUser'), prop: 'updateUser', slot: 'updateUser', width: 130 },
	{ label: $t('table.operation'), fixed: 'right', width: 160, slot: 'operation' },
];

// 添加规则
export const rules = reactive<FormRules>({
	// 绑定的用户
	userId: [{ required: true, message: `${$t('input')}${$t('userId')}`, trigger: 'blur' }],
	// 债务金额
	installmentNumber: [{ required: true, message: `${$t('input')}${$t('installmentNumber')}`, trigger: 'blur' }],
	// 每期应还金额
	installmentAmount: [{ required: true, message: `${$t('input')}${$t('installmentAmount')}`, trigger: 'blur' }],
	// 还款截止日期
	dueDate: [{ required: true, message: `${$t('input')}${$t('dueDate')}`, trigger: 'blur' }],
	// 已还金额
	paidAmount: [{ required: true, message: `${$t('input')}${$t('paidAmount')}`, trigger: 'blur' }],
	// 还款状态
	paymentStatus: [{ required: true, message: `${$t('input')}${$t('paymentStatus')}`, trigger: 'blur' }],
});
