import { addDialog } from '@/components/BaseDialog/index';
import DebtTrackingDialog from '@/views/financial/debt/debt-tracking/debt-tracking-dialog.vue';
import { useDebtTrackingStore } from '@/store/financial/debtTracking';
import { h, ref } from 'vue';
import { message, messageBox } from '@/utils/message';
import type { FormItemProps } from '@/views/financial/debt/debt-tracking/utils/types';
import { $t } from '@/plugins/i18n';
import DeleteBatchDialog from '@/components/Table/DeleteBatchDialog.vue';

export const formRef = ref();
// 删除ids
export const deleteIds = ref([]);
const debtTrackingStore = useDebtTrackingStore();

/** 搜索初始化债务追踪 */
export async function onSearch() {
	debtTrackingStore.loading = true;
	await debtTrackingStore.getDebtTrackingList();
	debtTrackingStore.loading = false;
}

/** 添加债务追踪 */
export function onAdd() {
	addDialog({
		title: `${$t('addNew')}${$t('debtTracking')}`,
		width: '30%',
		props: {
			formInline: {
				userId: undefined,
				debtorName: undefined,
				debtAmount: undefined,
				debtType: undefined,
				debtStatus: undefined,
				dueDate: undefined,
			},
		},
		draggable: true,
		fullscreenIcon: true,
		closeOnClickModal: false,
		contentRenderer: () => h(DebtTrackingDialog, { ref: formRef }),
		beforeSure: (done, { options }) => {
			const form = options.props.formInline as FormItemProps;
			formRef.value.formRef.validate(async (valid: any) => {
				if (!valid) return;

				const result = await debtTrackingStore.addDebtTracking(form);
				if (!result) return;
				done();
				await onSearch();
			});
		},
	});
}

/** 更新债务追踪 */
export function onUpdate(row: any) {
	addDialog({
		title: `${$t('modify')}${$t('debtTracking')}`,
		width: '30%',
		props: {
			formInline: {
				userId: row.userId,
				debtorName: row.debtorName,
				debtAmount: row.debtAmount,
				debtType: row.debtType,
				debtStatus: row.debtStatus,
				dueDate: row.dueDate,
			},
		},
		draggable: true,
		fullscreenIcon: true,
		closeOnClickModal: false,
		contentRenderer: () => h(DebtTrackingDialog, { ref: formRef }),
		beforeSure: (done, { options }) => {
			const form = options.props.formInline as FormItemProps;
			formRef.value.formRef.validate(async (valid: any) => {
				if (!valid) return;

				const result = await debtTrackingStore.updateDebtTracking({ ...form, id: row.id });
				if (!result) return;
				done();
				await onSearch();
			});
		},
	});
}

/** 删除债务追踪 */
export const onDelete = async (row: any) => {
	const id = row.id;

	// 是否确认删除
	const result = await messageBox({
		title: $t('confirmDelete'),
		showMessage: false,
		confirmMessage: undefined,
		cancelMessage: $t('cancel_delete'),
	});
	if (!result) return;

	// 删除数据
	await debtTrackingStore.deleteDebtTracking([id]);
	await onSearch();
};

/** 批量删除 */
export const onDeleteBatch = async () => {
	const ids = deleteIds.value;
	const formDeletedBatchRef = ref();

	addDialog({
		title: $t('deleteBatchTip'),
		width: '30%',
		props: { formInline: { confirmText: '' } },
		draggable: true,
		fullscreenIcon: true,
		closeOnClickModal: false,
		contentRenderer: () => h(DeleteBatchDialog, { ref: formDeletedBatchRef }),
		beforeSure: (done, { options }) => {
			formDeletedBatchRef.value.formDeletedBatchRef.validate(async (valid: any) => {
				if (!valid) return;

				const text = options.props.formInline.confirmText.toLowerCase();
				if (text === 'yes' || text === 'y') {
					// 删除数据
					await debtTrackingStore.deleteDebtTracking(ids);
					await onSearch();

					done();
				} else message($t('deleteBatchTip'), { type: 'warning' });
			});
		},
	});
};
